@@ -4,7 +4,7 @@ from django.db import transaction
 from structlog import get_logger
 
 from .. import psp
-from ..models import CreditCard, Invoice, Transaction
+from ..models import CreditCard, Invoice, Transaction, Account
 
 logger = get_logger()
 
@@ -13,23 +13,27 @@ class PreconditionError(Exception):
     pass
 
 
-def pay_with_account_credit_cards(
-    invoice_id,
-    exclude_reka_ccs=False
-) -> Optional[Transaction]:
+def pay_with_account_credit_cards(invoice_id) -> Optional[Transaction]:
     """
     Get paid for the invoice, trying the valid credit cards on record for the account.
 
     If successful attaches the payment to the invoice and marks the invoice as paid.
 
     :param invoice_id: the id of the invoice to pay.
-    :param exclude_reka_ccs: Temporal param to exclude reka credit cards
     :return: A successful transaction, or None if we weren't able to pay the invoice.
     """
     logger.debug('invoice-payment-started', invoice_id=invoice_id)
     with transaction.atomic():
         invoice = Invoice.objects.select_for_update().get(pk=invoice_id)
 
+        #
+        # Precondition: Account has to be open
+        #
+        if invoice.account.status == Account.CLOSED:
+            raise PreconditionError(
+                f'Cannot pay invoice with closed account {invoice.account}.'
+            )
+
         #
         # Precondition: Invoice should be in a state that allows payment
         #
@@ -52,8 +56,6 @@ def pay_with_account_credit_cards(
         # Try valid credit cards until one works. Start with the active ones
         #
         valid_credit_cards = CreditCard.objects.valid().filter(account=invoice.account)
-        if exclude_reka_ccs:
-            valid_credit_cards = valid_credit_cards.exclude(type='REK')
         valid_credit_cards = valid_credit_cards.order_by('status')
         if not valid_credit_cards:
             raise PreconditionError('No valid credit card on account.')
